@@ -1,6 +1,6 @@
 context("explain")
 
-x <- connect(warn = FALSE)
+x <- connect(port = Sys.getenv("TEST_ES_PORT"), warn = FALSE)
 load_shakespeare(x)
 Sys.sleep(1.5)
 
